'use strict';

const logger = spark.getLogger("testVanish");
if (!ll.listPlugins().includes("vanish")) { //检测是否装载完全隐身插件
    logger.warn("检测到未装载vanish");
    logger.warn("本次将不加载此插件");
    return;
} else {
    //导入json
    const JSON5 = require('json5');

    //设置配置文件目录
    const config = spark.getFileHelper('testVanish');

    //初始化语言文件
    config.initFile('lang.json', {
        join: '%PLAYER_NAME% 进入了服务器',
        left: '%PLAYER_NAME% 离开了服务器'
    });

    //读取语言文件
    const lang = JSON5.parse(config.getFile('lang.json'));

    const GROUP_ID = spark.mc.config.group; //获取群号

    spark.Cmd.regPlaceHolder('PLAYER_NAME', e => { //替换PLAYER_NAME为玩家名
        return e.realName;
    });

    spark.mc.on('onJoin', (player) => { //检测加入游戏
        if (player.isSimulatedPlayer() || (ll.listPlugins().includes("vanish") && player.isInvisible)) { //检测是否为假人以及是否隐身
            return;
        } else {
            spark.QClient.sendGroupMsg(GROUP_ID, spark.Cmd.buildString(lang.join, [], player)); //若未隐身则发送玩家加入消息
        }
    });

    spark.mc.on('onLeft', (player) => { //检测退出游戏
        if (player.isSimulatedPlayer() || (ll.listPlugins().includes("vanish") && player.isInvisible)) { //检测是否为假人以及是否隐身
            return;
        } else {
            spark.QClient.sendGroupMsg(GROUP_ID, spark.Cmd.buildString(lang.left, [], player)); //若未隐身则发送玩家退出消息
        }
    });

    setInterval(() => { //每秒检测隐身
        mc.getOnlinePlayers().forEach(player => { //遍历检测玩家
            if (player.isSimulatedPlayer()) { //检测是否为假人
                return;
            } else {
                //初始化数据文件
                config.initFile('data.json', {
                    [player.uuid]: false
                });
                let data = JSON5.parse(config.getFile('data.json')); //读取数据文件
                let state = ll.listPlugins().includes("vanish") && player.isInvisible; //检测是否隐身
                if (state != data[player.uuid]) { //如果数据文件中的状态和当前状态不同,则发送对应的消息
                    if (!state) {
                        spark.QClient.sendGroupMsg(GROUP_ID, spark.Cmd.buildString(lang.join, [], player));
                    } else {
                        spark.QClient.sendGroupMsg(GROUP_ID, spark.Cmd.buildString(lang.left, [], player));
                    }
                }
                data[player.uuid] = state; //将数据文件中的状态设置为当前状态
                config.updateFile("data.json", data); //更新数据文件
            }
        });
    }, 999);

    //兼容网页设置
    if (spark.telemetry.WebConfigBuilder != null) {
        const WebConfigBuilder = spark.telemetry.WebConfigBuilder;
        let wbc = new WebConfigBuilder("testVanish");
        wbc.addText("join", lang.join, "加入服务器向群聊中发送的消息");
        wbc.addText("left", lang.left, '离开服务器向群聊中发送的消息');
        spark.emit("event.telemetry.pushconfig", wbc);
        spark.on("event.telemetry.updateconfig_testVanish", (p, k, v) => {
            switch (k) {
                case 'join':
                    lang.join = v;
                    break;
                case 'left':
                    lang.left = v;
                    break;
            }
            config.updateFile("lang.json", lang);
        });
    }
}











